@@ -317,6 +317,8 @@ class OptionsManager:
 
         self.options.append(TickOption(_("Search as you type"), "instantSearch"))
 
+        self.options.append(TickOption(_("Auto indent"), "autoIndent"))
+
         def check_version_action(widget):
             utils.check_new_version(
                 self.main_window.journal, info.version, startup=False
@@ -379,9 +381,12 @@ class OptionsManager:
             # Apply some options
             self.main_window.cloud.update_lists()
             self.main_window.cloud.update(force_update=True)
+            self.main_window.set_auto_indent()
 
             visible = self.config.read("closeToTray") == 1
-            self.main_window.tray_icon.set_visible(visible)
+            # The tray icon is now only instantiated on Windows.
+            if hasattr(self.main_window, "tray_icon"):
+                self.main_window.tray_icon.set_visible(visible)
         else:
             # Reset some options
             self.main_window.set_font(self.config.read("mainFont", editor.DEFAULT_FONT))
